@@ -8,7 +8,6 @@
 #ifndef BALOO_ENGINE_DOCUMENT_OPERATIONS_H
 #define BALOO_ENGINE_DOCUMENT_OPERATIONS_H
 
-
 namespace Baloo {
 
 enum DocumentOperation {
@@ -18,7 +17,7 @@ enum DocumentOperation {
     DocumentData  =  0x8,
     DocumentTime  = 0x10,
     DocumentUrl   = 0x20,
-    Everything    = DocumentTerms | FileNameTerms | XAttrTerms | DocumentData | DocumentTime | DocumentUrl
+    Everything    = DocumentTerms | FileNameTerms | XAttrTerms | DocumentData | DocumentTime | DocumentUrl,
 };
 Q_DECLARE_FLAGS(DocumentOperations, DocumentOperation)
 Q_DECLARE_OPERATORS_FOR_FLAGS(DocumentOperations)
