@@ -1,19 +1,8 @@
-/* This file is part of the KDE Project
-   Copyright (c) 2008-2010 Sebastian Trueg <trueg@kde.org>
+/*
+    This file is part of the KDE Project
+    SPDX-FileCopyrightText: 2008-2010 Sebastian Trueg <trueg@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fileexcludefilters.h"
@@ -45,6 +34,9 @@ const char* const s_defaultFileExcludeFilters[] = {
     "confstat",
     "Makefile.am",
     "*.gcode", // CNC machine/3D printer toolpath files
+    ".ninja_deps",
+    ".ninja_log",
+    "build.ninja",
 
     // misc
     "*.csproj",
@@ -59,6 +51,7 @@ const char* const s_defaultFileExcludeFilters[] = {
     "*.vm*",
     "*.nvram",
     "*.rcore",
+    "*.swp",
     "*.swap",
     "lzo",
     "litmain.sh",
@@ -82,6 +75,7 @@ const char* const s_defaultFileExcludeFilters[] = {
     "*.vhdx",   // Hyper-V disk images
     "*.sql",     // SQL database dumps
     "*.sql.gz",  // Compressed SQL database dumps
+    "*.ytdl",    // youtube-dl temp files
 
     // Bytecode files
     "*.class", // Java
@@ -104,7 +98,7 @@ const char* const s_defaultFileExcludeFilters[] = {
     nullptr
 };
 
-const int s_defaultFileExcludeFiltersVersion = 5;
+const int s_defaultFileExcludeFiltersVersion = 8;
 
 const char* const s_defaultFolderExcludeFilters[] = {
     "po",
@@ -132,6 +126,8 @@ const char* const s_defaultFolderExcludeFilters[] = {
     "node_modules",
     "node_packages",
     "nbproject",
+    ".venv",
+    "venv",
 
     //misc
     "core-dumps",
@@ -141,7 +137,7 @@ const char* const s_defaultFolderExcludeFilters[] = {
     nullptr
 };
 
-const int s_defaultFolderExcludeFiltersVersion = 2;
+const int s_defaultFolderExcludeFiltersVersion = 3;
 
 const char* const s_sourceCodeMimeTypes[] = {
     "text/css",
@@ -197,14 +193,15 @@ const char* const s_sourceCodeMimeTypes[] = {
 const int s_sourceCodeMimeTypesVersion = 3;
 }
 
-
 QStringList Baloo::defaultExcludeFilterList()
 {
     QStringList l;
-    for (int i = 0; s_defaultFileExcludeFilters[i]; ++i)
+    for (int i = 0; s_defaultFileExcludeFilters[i]; ++i) {
         l << QLatin1String(s_defaultFileExcludeFilters[i]);
-    for (int i = 0; s_defaultFolderExcludeFilters[i]; ++i)
+    }
+    for (int i = 0; s_defaultFolderExcludeFilters[i]; ++i) {
         l << QLatin1String(s_defaultFolderExcludeFilters[i]);
+    }
     return l;
 }
 
@@ -216,8 +213,9 @@ int Baloo::defaultExcludeFilterListVersion()
 QStringList Baloo::sourceCodeMimeTypes()
 {
     QStringList l;
-    for (int i = 0; s_sourceCodeMimeTypes[i]; ++i)
+    for (int i = 0; s_sourceCodeMimeTypes[i]; ++i) {
         l << QLatin1String(s_sourceCodeMimeTypes[i]);
+    }
 
     return l;
 }
