@@ -12,13 +12,12 @@
 namespace Baloo
 {
 
-const QJsonObject propertyMapToJson(const KFileMetaData::PropertyMap& properties)
+const QJsonObject propertyMapToJson(const KFileMetaData::PropertyMultiMap& properties)
 {
     auto it = properties.cbegin();
     QJsonObject jsonDict;
 
     while (it != properties.cend()) {
-
         auto property = it.key();
         QString keyString = QString::number(static_cast<int>(property));
 
@@ -61,9 +60,9 @@ const QJsonObject propertyMapToJson(const KFileMetaData::PropertyMap& properties
     return jsonDict;
 }
 
-const KFileMetaData::PropertyMap jsonToPropertyMap(const QJsonObject& properties)
+const KFileMetaData::PropertyMultiMap jsonToPropertyMap(const QJsonObject& properties)
 {
-    KFileMetaData::PropertyMap propertyMap;
+    KFileMetaData::PropertyMultiMap propertyMap;
 
     auto it = properties.begin();
     while (it != properties.end()) {
@@ -73,13 +72,13 @@ const KFileMetaData::PropertyMap jsonToPropertyMap(const QJsonObject& properties
         if (it.value().isArray()) {
             const auto values = it.value().toArray();
             for (const auto val : values) {
-                propertyMap.insertMulti(prop, val.toVariant());
+                propertyMap.insert(prop, val.toVariant());
             }
 
         } else if (it.value().isDouble()) {
-            propertyMap.insertMulti(prop, it.value().toDouble());
+            propertyMap.insert(prop, it.value().toDouble());
         } else {
-            propertyMap.insertMulti(prop, it.value().toString());
+            propertyMap.insert(prop, it.value().toString());
         }
         ++it;
     }
