@@ -17,7 +17,7 @@
 
 using namespace Baloo;
 
-class IndexerConfig::Private {
+class BALOO_CORE_NO_EXPORT IndexerConfig::Private {
 public:
     FileIndexerConfig m_config;
     BalooSettings m_settings;
@@ -39,7 +39,6 @@ bool IndexerConfig::fileIndexingEnabled() const
     return d->m_settings.indexingEnabled();
 }
 
-
 void IndexerConfig::setFileIndexingEnabled(bool enabled) const
 {
     d->m_settings.setIndexingEnabled(enabled);
@@ -50,7 +49,6 @@ bool IndexerConfig::shouldBeIndexed(const QString& path) const
     return d->m_config.shouldBeIndexed(path);
 }
 
-
 bool IndexerConfig::canBeSearched(const QString& folder) const
 {
     return d->m_config.canBeSearched(folder);
