@@ -14,7 +14,7 @@
 
 using namespace Baloo;
 
-class TagListJob::Private {
+class BALOO_CORE_NO_EXPORT TagListJob::Private {
 public:
     QStringList tags;
 };
@@ -64,3 +64,5 @@ QStringList TagListJob::tags()
 {
     return d->tags;
 }
+
+#include "moc_taglistjob.cpp"
