@@ -6,13 +6,16 @@
 
 #include "baloomonitorplugin.h"
 #include "monitor.h"
+#include "indexerstate.h"
 
-#include <QtQml>
+#include <QQmlEngine>
 
 void BalooMonitorPlugin::registerTypes(const char *uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.baloo.experimental"));
+    Q_ASSERT(uri == QByteArrayLiteral("org.kde.baloo.experimental"));
 
     qmlRegisterType<Baloo::Monitor>(uri, 0, 1, "Monitor");
+    qmlRegisterUncreatableMetaObject(Baloo::staticMetaObject, uri, 0, 1, "Global", QStringLiteral("Error: only enums"));
 }
 
+#include "moc_baloomonitorplugin.cpp"
